$1 = Get-Content -Path NASWOL.ini | Where-Object { $_ -match 'NAS=' }
$2 = Get-Content -Path NASWOL.ini | Where-Object { $_ -match 'NASIP=' }
$3 = Get-Content -Path NASWOL.ini | Where-Object { $_ -match 'NASMAC=' }
$4 = Get-Content -Path NASWOL.ini | Where-Object { $_ -match 'WAIT=' }

$NAS = $1.Split('=')[1]
$NASIP = $2.Split('=')[1]
$NASMAC = $3.Split('=')[1]
$WAIT = $4.Split('=')[1]

function Send-WOL 
{ 
<#  
  .SYNOPSIS   
    Send a WOL packet to a broadcast address 
  .PARAMETER mac 
   The MAC address of the device that need to wake up 
  .PARAMETER ip 
   The IP address where the WOL packet will be sent to 
  .EXAMPLE  
   Send-WOL -mac 00:11:32:21:2D:11 -ip 192.168.8.255  
  .EXAMPLE  
   Send-WOL -mac 00:11:32:21:2D:11  
 
#> 
 
[CmdletBinding()] 
param( 
[Parameter(Mandatory=$True,Position=1)] 
[string]$mac, 
[string]$ip="255.255.255.255",  
[int]$port=9 
) 
$broadcast = [Net.IPAddress]::Parse($ip) 
  
$mac=(($mac.replace(":","")).replace("-","")).replace(".","") 
$target=0,2,4,6,8,10 | % {[convert]::ToByte($mac.substring($_,2),16)} 
$packet = (,[byte]255 * 6) + ($target * 16) 
  
$UDPclient = new-Object System.Net.Sockets.UdpClient 
$UDPclient.Connect($broadcast,$port) 
[void]$UDPclient.Send($packet, 102)  
 
} 


if (Test-Connection "$NASIP" -Quiet) 
{
	if ($($env:USERNAME) -imatch "Timo")
	{
	write-host "-------------" -ForegroundColor Green
	write-host "$NAS online..." -ForegroundColor Green
	write-host "-------------" -ForegroundColor Green
	write-host "Verbinde Netzlaufwerke..." -ForegroundColor Green
	write-host "-------------------------" -ForegroundColor Green
	write-host "Verbinde $NAS\Timo als T:..." -ForegroundColor Green
	$Network = New-Object -ComObject "Wscript.Network"
	$Network.MapNetworkDrive("T:","\\$NAS\Timo",0,"User","Passwort")
	(New-Object -ComObject Shell.Application).NameSpace('T:').Self.Name='Timo'
	write-host "-------------------------" -ForegroundColor Green
	write-host "Verbinde $NAS\Gemeinsam als G:..." -ForegroundColor Green
	$Network = New-Object -ComObject "Wscript.Network"
	$Network.MapNetworkDrive("G:", "\\$NAS\Gemeinsam")
	(New-Object -ComObject Shell.Application).NameSpace('G:').Self.Name='Gemeinsam'
	write-host "-------------------------" -ForegroundColor Green
	write-host "Verbinde $NAS\Filme als F:..." -ForegroundColor Green
	$Network = New-Object -ComObject "Wscript.Network"
	$Network.MapNetworkDrive("F:", "\\$NAS\Filme")
	(New-Object -ComObject Shell.Application).NameSpace('F:').Self.Name='Filme'
	}
	else
	{
	write-host "-------------" -ForegroundColor Green
	write-host "$NAS online..." -ForegroundColor Green
	write-host "-------------" -ForegroundColor Green
	write-host "Verbinde Netzlaufwerke..." -ForegroundColor Green
	write-host "-------------------------" -ForegroundColor Green
	write-host "Verbinde $NAS\Judith als J:..." -ForegroundColor Green
	$Network = New-Object -ComObject "Wscript.Network"
	$Network.MapNetworkDrive("T:","\\$NAS\Benutzer",0,"User","Passwort")
	(New-Object -ComObject Shell.Application).NameSpace('J:').Self.Name='Benutzer'
	write-host "-------------------------" -ForegroundColor Green
	write-host "Verbinde $NAS\Gemeinsam als G:..." -ForegroundColor Green
	$Network = New-Object -ComObject "Wscript.Network"
	$Network.MapNetworkDrive("G:", "\\$NAS\Gemeinsam")
	(New-Object -ComObject Shell.Application).NameSpace('G:').Self.Name='Gemeinsam'
	}
} 

else 
{
write-host "---------------" -ForegroundColor Red
write-host "$NAS offline..." -ForegroundColor Red
write-host "---------------" -ForegroundColor Red
write-host "Starte $NAS..." -ForegroundColor Red

Send-WOL -mac $NASMAC

write-host "--------------------------------------" -ForegroundColor Red
write-host "Warte $WAIT Sek. auf Start von $NAS..." -ForegroundColor Red

Start-Sleep -Seconds $WAIT

write-host ""

if ($($env:USERNAME) -imatch "Timo")
	{
	write-host "-------------" -ForegroundColor Green
	write-host "$NAS online..." -ForegroundColor Green
	write-host "-------------" -ForegroundColor Green
	write-host "Verbinde Netzlaufwerke..." -ForegroundColor Green
	write-host "-------------------------" -ForegroundColor Green
	write-host "Verbinde $NAS\Timo als T:..." -ForegroundColor Green
	$Network = New-Object -ComObject "Wscript.Network"
	$Network.MapNetworkDrive("T:","\\$NAS\Timo",0,"User","Passwort")
	(New-Object -ComObject Shell.Application).NameSpace('T:').Self.Name='Timo'
	write-host "-------------------------" -ForegroundColor Green
	write-host "Verbinde $NAS\Gemeinsam als G:..." -ForegroundColor Green
	$Network = New-Object -ComObject "Wscript.Network"
	$Network.MapNetworkDrive("G:", "\\$NAS\Gemeinsam")
	(New-Object -ComObject Shell.Application).NameSpace('G:').Self.Name='Gemeinsam'
	write-host "-------------------------" -ForegroundColor Green
	write-host "Verbinde $NAS\Filme als F:..." -ForegroundColor Green
	$Network = New-Object -ComObject "Wscript.Network"
	$Network.MapNetworkDrive("F:", "\\$NAS\Filme")
	(New-Object -ComObject Shell.Application).NameSpace('F:').Self.Name='Filme'
	}
	else
	{
	write-host "-------------" -ForegroundColor Green
	write-host "$NAS online..." -ForegroundColor Green
	write-host "-------------" -ForegroundColor Green
	write-host "Verbinde Netzlaufwerke..." -ForegroundColor Green
	write-host "-------------------------" -ForegroundColor Green
	write-host "Verbinde $NAS\Judith_aus als J:..." -ForegroundColor Green
	$Network = New-Object -ComObject "Wscript.Network"
	$Network.MapNetworkDrive("J:","\\$NAS\User",0,"User","Passwort")
	(New-Object -ComObject Shell.Application).NameSpace('J:').Self.Name='User'
	write-host "-------------------------" -ForegroundColor Green
	write-host "Verbinde $NAS\Gemeinsam als G:..." -ForegroundColor Green
	$Network = New-Object -ComObject "Wscript.Network"
	$Network.MapNetworkDrive("G:", "\\$NAS\Gemeinsam")
	(New-Object -ComObject Shell.Application).NameSpace('G:').Self.Name='Gemeinsam'
	}

}

